@@ -41,12 +41,18 @@ class MiniNode:
         self.group_id = info["group_id"]
         self.aes_key = bytes.fromhex(info["chiperkey"])
 
-    def create_private_key(self):
+    @staticmethod
+    def create_private_key() -> str:
         acc = Account.create()
         private_key = encode_hex(acc.privateKey)
         return private_key
 
-    def check_private_key(self, private_key: str) -> bytes:
+    @staticmethod
+    def private_key_to_address(private_key) -> str:
+        return Account.from_key(private_key).address
+
+    @staticmethod
+    def check_private_key(private_key: str) -> bytes:
         if isinstance(private_key, int):
             private_key = hex(private_key)
         if isinstance(private_key, str):
@@ -64,6 +70,16 @@ class MiniNode:
             raise ParamValueError("Invalid private key. param private_key is required.eg:  private_key=xxx")
         return private_key
 
+    @staticmethod
+    def private_key_to_keystore(private_key, password: str):
+        return Account.from_key(private_key).encrypt(password=password)
+
+    @staticmethod
+    def keystore_to_private_key(keystore: Dict, password: str) -> str:
+        pvtkey = Account.decrypt(keystore, password)
+        private_key = encode_hex(pvtkey)
+        return private_key
+
     def send_note(
         self,
         private_key,
@@ -77,13 +93,19 @@ class MiniNode:
         seedurl=None,
     ):
         obj = Mini.pack_note_obj(content, name, images, edit_trx_id, del_trx_id, reply_trx_id)
-        return self.send_trx(private_key, obj, timestamp, seedurl)
+        return self.send_trx(private_key, obj=obj, timestamp=timestamp, seedurl=seedurl)
 
     def like(self, private_key, trx_id, like_type="Like", timestamp=None, seedurl=None):
         obj = Mini.pack_like_obj(trx_id, like_type)
-        return self.send_trx(private_key, obj, timestamp, seedurl)
+        return self.send_trx(private_key, obj=obj, timestamp=timestamp, seedurl=seedurl)
 
-    def send_trx(self, private_key, obj, timestamp=None, seedurl=None):
+    def update_profile(self, private_key, name=None, image=None, timestamp=None, seedurl=None):
+        if name is None and image is None:
+            raise ParamValueError("Invalid profile. param name or image is required.eg:  name=xxx or image=xxx")
+        person = Mini.pack_person_obj(name=name, image=image)
+        return self.send_trx(private_key, person=person, timestamp=timestamp, seedurl=seedurl)
+
+    def send_trx(self, private_key, obj=None, person=None, timestamp=None, seedurl=None):
         """
         obj: dict,packed from rumpy.types.pack_trx
         timestamp:2022-10-05 12:34
@@ -95,7 +117,7 @@ class MiniNode:
         if timestamp and isinstance(timestamp, str):
             timestamp = timestamp.replace("/", "-")[:16]
             timestamp = time.mktime(time.strptime(timestamp, "%Y-%m-%d %H:%M"))
-        trx = trx_encrypt(self.group_id, self.aes_key, private_key, obj, timestamp)
+        trx = trx_encrypt(self.group_id, self.aes_key, private_key, obj=obj, person=person, timestamp=timestamp)
         return self.http.post(endpoint=f"/node/trx/{self.group_id}", payload=trx)
 
     def get_trx(self, trx_id):
